@@ -39,11 +39,11 @@ class SessionPrice:
             "price": self._total_price
         }
 
-    def update_power_reading(self, power: float, mock_time: float=None):
+    def update_power_reading(self, power: any, mock_time: float=None):
         self._set_delta(mock_time)
         p = PowerReading(self._price, self._current_power, self._time_delta)
         self._readings.append(p)
-        self._current_power = power
+        self._current_power = float(power)
 
     def update_price(self, price: float, mock_time: float=None):
         if self._current_power > 0:
