@@ -1,5 +1,10 @@
+from datetime import datetime
+
 def _convert_quarterly_minutes(minute:int, is_quarterly:bool) -> int:
     if is_quarterly is True:
         return (minute%15) * 4
     else:
-        return minute
\ No newline at end of file
+        return minute
+
+def parse_datetime(dtstring:str) -> datetime:
+    pass
\ No newline at end of file
